{
    "$graph": [
        {
            "class": "Workflow",
            "label": "process VCF workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#add_strelka_gt.cwl",
                    "in": [
                        {
                            "source": "#main/vcf",
                            "id": "#main/add_gt/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_gt/processed_vcf"
                    ],
                    "id": "#main/add_gt"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/add_gt/processed_vcf",
                            "id": "#main/bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip/bgzipped_file"
                    ],
                    "id": "#main/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip/bgzipped_file",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/processed_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "add GT tags",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "add_strelka_gt.pl",
                            "entry": "#!/usr/bin/perl\n\nuse strict;\nuse warnings;\n\nuse feature qw(say);\n\ndie(\"wrong number of arguments\") unless scalar(@ARGV) == 2;\nmy ($strelka_vcf, $outdir) = @ARGV;\n\nopen(my $strelka_vcf_fh, '-|', '/bin/gunzip', '-c', $strelka_vcf) \n    or die(\"couldn't open $strelka_vcf to read\");\nopen(my $add_gt_fh, \">\", \"$outdir/add_gt.vcf\") \n    or die(\"couldn't open add_gt.vcf for write\");\n\nwhile (<$strelka_vcf_fh>) {\n    chomp;\n    if (/^##/) {\n        say $add_gt_fh $_;\n    }\n    elsif (/^#/) { #COLUMN HEADER\n        say $add_gt_fh '##FORMAT=<ID=GT,Number=1,Type=String,Description=\"Genotype\">';\n        say $add_gt_fh $_;\n    }\n    else {\n        my @columns = split /\\t/, $_;\n        my ($ref, $alt, $info) = map{$columns[$_]}(3, 4, 7);\n        my @alts = split /,/, $alt;\n\n        my ($n_gt, $t_gt);\n\n        if (length($ref) == 1 and length($alts[0]) == 1) {\n            my ($n_gt_info, $n_gt_str, $t_gt_str) = $info =~ /NT=(\\S+?);QSS.*SGT=(\\S+?)\\->(\\S+?);/;\n            unshift @alts, $ref;\n\n            my %ids;\n            my $id = 0;\n\n            for my $base (@alts) {\n                $ids{$base} = $id;\n                $id++;\n            }\n\n            $n_gt = $n_gt_info eq 'ref' ? '0/0' : parse_gt($n_gt_str, \\%ids);\n            $t_gt = parse_gt($t_gt_str, \\%ids);\n        }\n        else {#INDEL\n            my ($n_gt_info, $t_gt_info) = $info =~ /;NT=(\\S+?);.*SGT.*\\->(\\S+?);/;\n\n            my %gt_info = (\n                ref => '0/0',\n                het => '0/1',\n                hom => '1/1',\n                conflict => './.',\n            );\n\n            $n_gt = $gt_info{$n_gt_info};\n            $t_gt = $gt_info{$t_gt_info};\n        }\n\n        $columns[8]  = 'GT:'.$columns[8];\n        $columns[9]  = $n_gt . ':' . $columns[9];\n        $columns[10] = $t_gt . ':' . $columns[10];\n\n        my $new_str = join \"\\t\", @columns;\n        say $add_gt_fh $new_str;\n    }\n}\n\nclose($strelka_vcf_fh);\nclose($add_gt_fh);\n\n\nsub parse_gt {\n    my ($gt_str, $ids) = @_;\n    my @gt_ids = map{$ids->{$_}}(split //, $gt_str);\n    return join '/', sort @gt_ids;\n}\n"
                        }
                    ]
                }
            ],
            "arguments": [
                "/usr/bin/perl",
                "add_strelka_gt.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#add_strelka_gt.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "add_gt.vcf"
                    },
                    "id": "#add_strelka_gt.cwl/processed_vcf"
                }
            ],
            "id": "#add_strelka_gt.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/usr/local/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "jbwebster/snv_pipeline_docker"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/local/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "jbwebster/snv_pipeline_docker"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
